%define upver 1.4
%define uprel 13

# If the emacs-el package has installed a pkgconfig file, use that to determine
# install locations and Emacs version at build time, otherwise set defaults.
%if %($(pkg-config emacs) ; echo $?)
%define emacs_version 22.1
%define emacs_lispdir %{_datadir}/emacs/site-lisp
%else
%define emacs_version %(pkg-config emacs --modversion)
%define emacs_lispdir %(pkg-config emacs --variable sitepkglispdir)
%endif

# If the xemacs-devel package has installed a pkgconfig file, use that to
# determine install locations and Emacs version at build time, otherwise set
# defaults.
%if %($(pkg-config xemacs) ; echo $?)
%define xemacs_version 21.5
%define xemacs_lispdir %{_datadir}/xemacs/site-packages/lisp
%else
%define xemacs_version %(pkg-config xemacs --modversion)
%define xemacs_lispdir %(pkg-config xemacs --variable sitepkglispdir)
%endif

Name:           mona
Version:        %{upver}r%{uprel}
Release:        1%{?dist}
Summary:        A decision procedure for the WS1S and WS2S logics

Group:          Applications/Engineering
License:        GPLv2+
URL:            http://www.brics.dk/mona/
Source0:        http://www.brics.dk/~amoeller/mona/download/mona-%{upver}-%{uprel}.tar.gz
Source1:        http://www.brics.dk/mona/mona14.pdf
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  libtool, emacs, emacs-el, xemacs, xemacs-devel

%description
MONA is a tool that translates formulas in the logics WS1S or WS2S into
finite-state automata represented by BDDs.  The formulas may express search
patterns, temporal properties of reactive systems, parse tree constraints,
etc.  MONA also analyses the automaton resulting from the compilation, and
determines whether the formula is valid and, if the formula is not valid,
generates a counterexample.

%package libs
Group:          Applications/Engineering
Summary:        Supporting libraries for Mona

%description libs
Supporting libraries for Mona.

%package devel
Group:          Applications/Engineering
Summary:        Header files for developing applications with Mona
Requires:       %{name}-libs = %{version}-%{release}

%description devel
Header files for developing applications that use the Mona libraries.

%package examples
Group:          Applications/Engineering
Summary:        Example Mona source files and C programs
Requires:       %{name}-libs = %{version}-%{release}

%description examples
Example Mona source files, for use with the mona executable, and also sample C
programs that access the Mona library interfaces.

%package emacs
Group:          Applications/Engineering
Summary:        Emacs mode for editing Mona files
Requires:       %{name}-libs = %{version}-%{release}, emacs(bin) >= %{emacs_version}

%description emacs
Emacs mode for editing Mona files.

%package emacs-el
Group:          Applications/Engineering
Summary:        Source for Emacs mode for editing Mona files
Requires:       %{name}-emacs = %{version}-%{release}

%description emacs-el
Source Elisp code for Emacs mode for editing Mona files.

%package xemacs
Group:          Applications/Engineering
Summary:        XEmacs mode for editing Mona files
Requires:       %{name}-libs = %{version}-%{release}, xemacs(bin) >= %{xemacs_version}

%description xemacs
XEmacs mode for editing Mona files.

%package xemacs-el
Group:          Applications/Engineering
Summary:        Source for XEmacs mode for editing Mona files
Requires:       %{name}-xemacs = %{version}-%{release}

%description xemacs-el
Source Elisp code for XEmacs mode for editing Mona files.

%prep
%setup -q -n %{name}-%{upver}
cp -p %{SOURCE1} .

%build
%configure --disable-static
make %{?_smp_mflags} CFLAGS="${RPM_OPT_FLAGS}" CXXFLAGS="${RPM_OPT_FLAGS}"

%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT

# Get rid of the .la files; we don't want them
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la

# Install the examples
cp -p Examples/bdd_example $RPM_BUILD_ROOT%{_bindir}
cp -p Examples/gta_example $RPM_BUILD_ROOT%{_bindir}
cp -p Examples/presburger_analysis $RPM_BUILD_ROOT%{_bindir}
cp -p Examples/presburger_transduction $RPM_BUILD_ROOT%{_bindir}

# Move the Emacs lisp file to the right places
mkdir -p $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp/mona
mkdir -p $RPM_BUILD_ROOT%{_datadir}/xemacs/site-packages/lisp

cd $RPM_BUILD_ROOT%{_datadir}/emacs/site-lisp/mona
cp -p $RPM_BUILD_ROOT%{_datadir}/mona-mode.el .
emacs -batch -no-site-file -f batch-byte-compile mona-mode.el

cd $RPM_BUILD_ROOT%{_datadir}/xemacs/site-packages/lisp
mv $RPM_BUILD_ROOT%{_datadir}/mona-mode.el .
xemacs -batch -no-site-file -f batch-byte-compile mona-mode.el

%clean
rm -rf $RPM_BUILD_ROOT

%post libs -p /sbin/ldconfig

%postun libs -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog COPYING NEWS README mona14.pdf
%{_bindir}/mona
%{_bindir}/dfa2dot
%{_bindir}/gta2dot
%{_mandir}/man1/*

%files devel
%defattr(-,root,root,-)
%{_includedir}/mona
%{_libdir}/*.so

%files examples
%defattr(-,root,root,-)
%doc Examples/*.mona Examples/bdd_volatility
%{_bindir}/bdd_example
%{_bindir}/gta_example
%{_bindir}/presburger_analysis
%{_bindir}/presburger_transduction

%files libs
%defattr(-,root,root,-)
%{_libdir}/*.so.*

%files emacs
%defattr(-,root,root,-)
%dir %{emacs_lispdir}/mona
%{emacs_lispdir}/mona/mona-mode.elc

%files emacs-el
%defattr(-,root,root,-)
%{emacs_lispdir}/mona/mona-mode.el

%files xemacs
%defattr(-,root,root,-)
%dir %{xemacs_lispdir}
%{xemacs_lispdir}/mona-mode.elc

%files xemacs-el
%defattr(-,root,root,-)
%{xemacs_lispdir}/mona-mode.el

%changelog
* Mon Aug 11 2008 Jerry James <loganjerry@gmail.com> - 1.4r13-1
- Update to 1.4-13

* Mon Jun 17 2008 Jerry James <loganjerry@gmail.com> - 1.4r11-1
- Update to 1.4-11
- Add the user manual to the main package docs

* Mon Mar 10 2008 Jerry James <loganjerry@gmail.com> - 1.4r10-1
- Initial RPM
